<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/spip?lang_cible=vi
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'access_interface_graphique' => 'Trở lại giao diện ảnh ',
	'access_mode_texte' => 'Xem phần giao diện đơn giản',
	'admin_debug' => 'debug',
	'admin_modifier_article' => 'Sửa đổi bài này',
	'admin_modifier_auteur' => 'Sửa đổi tác giả này',
	'admin_modifier_breve' => 'Sửa đổi tin ngắn này',
	'admin_modifier_mot' => 'Sửa đổi từ then chốt này',
	'admin_modifier_rubrique' => 'Sửa đổi đề mục này',
	'admin_recalculer' => 'Cập nhật trang này',
	'afficher_trad' => 'xem các bản dịch',
	'alerte_maj_impossible' => '<b>Báo Động!</b> Không cập nhật database SQL lên ấn bản @version@ được, có thể là  vì không đủ quyền hạn. Xin liên lạc với ISP.',
	'alerte_modif_info_concourante' => 'ATTENTION : Cette information a été modifié par ailleurs. La valeur actuelle est :', # MODIF
	'analyse_xml' => 'Phân tách XML',
	'annuler' => 'Xoá',
	'antispam_champ_vide' => 'Để trống ô này:',
	'articles_recents' => 'Những bài mới nhất',
	'avis_archive_incorrect' => 'Hồ sơ này không phải là một hồ sơ SPIP',
	'avis_archive_invalide' => 'Hồ sơ này không có hợp lý',
	'avis_attention' => 'LƯU Ý!',
	'avis_champ_incorrect_type_objet' => 'Tên field @name@ không đúng cho dạng @type@',
	'avis_colonne_inexistante' => 'Không có cột nào tên @col@',
	'avis_erreur' => 'CÓ LỖI: xem dưới đây',
	'avis_erreur_connexion' => 'Có Lỗi: không nối được',
	'avis_erreur_cookie' => 'Có lỗi cookie',
	'avis_erreur_fonction_contexte' => 'Có lỗi programming. Function này không nên dùng trong bối cảnh này.', # MODIF
	'avis_erreur_mysql' => 'Có Lỗi-SQL', # MODIF
	'avis_erreur_sauvegarde' => 'Lỗi trong backup (@type@ @id_objet@)!',

	// B
	'barre_a_accent_grave' => 'Đánh vào chữ À',
	'barre_aide' => 'Sử dụng cách xếp bài tắt để trình bày văn bản',
	'barre_e_accent_aigu' => 'Đánh vào chữ É',
	'barre_eo' => 'Đánh vào chữ oe',
	'barre_eo_maj' => 'Đánh vào chữ OE',
	'barre_euro' => 'Thêm chữ €',
	'barre_gras' => 'Làm chữ {{đậm lên}}',
	'barre_guillemets' => 'Cho chữ vào giữa hai dấu «  »',
	'barre_guillemets_simples' => 'Cho chữ vào giữa hai dấu  ',
	'barre_intertitre' => 'Đổi thành {{{Chủ đề phụ}}}',
	'barre_italic' => 'Làm chữ {nghiêng}',
	'barre_lien' => 'Đổi thành [hyperlink-&gt;http://...]',
	'barre_lien_input' => 'Xin cho vào địa chỉ hyperlink (bạn có thể dùng Internet URL trong dạng http://www.mysite.com/ hoặc là số bài của trang web này).',
	'barre_note' => 'Đổi thành [[Ghi chú]]',
	'barre_quote' => '<quote>Trích dẫn một đoạn văn</quote>',
	'bouton_changer' => 'Thay đổi',
	'bouton_chercher' => 'Tìm',
	'bouton_choisir' => 'Chọn',
	'bouton_download' => 'Télécharger', # MODIF
	'bouton_enregistrer' => 'Lưu Trữ',
	'bouton_radio_desactiver_messagerie_interne' => 'Không sử dụng thư tín nội bộ ',
	'bouton_radio_envoi_annonces' => 'Gửi thông báo đến Ban Biên Tập',
	'bouton_radio_non_envoi_annonces' => 'Không gửi thông báo',
	'bouton_radio_non_envoi_liste_nouveautes' => 'Không gửi tin tức mới nhất',
	'bouton_recharger_page' => 'Nạp lại trang này',
	'bouton_telecharger' => 'Đem lên',
	'bouton_upload' => 'Đem lên', # MODIF
	'bouton_valider' => 'Cập nhật',

	// C
	'cal_apresmidi' => 'buổi chiều',
	'cal_jour_entier' => 'nguyên ngày',
	'cal_matin' => 'sáng',
	'cal_par_jour' => 'lịch trình hàng ngày',
	'cal_par_mois' => 'lịch trình hàng tháng',
	'cal_par_semaine' => 'lịch trình hàng tuần',
	'choix_couleur_interface' => 'màu',
	'choix_interface' => 'chọn lựa dao diện',
	'colonne' => 'Cột',
	'confirm_changer_statut' => 'Cần xác nhận: bạn yêu cầu thay đổi tình trạng của bài này. Bạn có muốn tiếp tục không?',
	'correcte' => 'đúng',

	// D
	'date_aujourdhui' => 'hôm nay',
	'date_avant_jc' => 'trước Công Nguyên',
	'date_dans' => 'trong @delai@',
	'date_de_mois_1' => '@j@ @nommois@',
	'date_de_mois_10' => '@j@ @nommois@',
	'date_de_mois_11' => '@j@ @nommois@',
	'date_de_mois_12' => '@j@ @nommois@',
	'date_de_mois_2' => '@j@ @nommois@',
	'date_de_mois_3' => '@j@ @nommois@',
	'date_de_mois_4' => '@j@ @nommois@',
	'date_de_mois_5' => '@j@ @nommois@',
	'date_de_mois_6' => '@j@ @nommois@',
	'date_de_mois_7' => '@j@ @nommois@',
	'date_de_mois_8' => '@j@ @nommois@',
	'date_de_mois_9' => '@j@ @nommois@',
	'date_demain' => 'ngày mai',
	'date_fmt_heures_minutes' => '@h@h@m@min',
	'date_fmt_jour_heure' => '@jour@ vào lúc @heure@',
	'date_fmt_jour_mois' => '@jour@ @nommois@',
	'date_fmt_jour_mois_annee' => '@jour@, @nommois@ @annee@',
	'date_fmt_mois_annee' => '@nommois@ @annee@',
	'date_fmt_nomjour_date' => 'vào @nomjour@ @date@',
	'date_heures' => 'giờ',
	'date_hier' => 'hôm qua',
	'date_il_y_a' => 'cách đây @delai@',
	'date_jnum1' => '1',
	'date_jnum10' => '10',
	'date_jnum11' => '11',
	'date_jnum12' => '12',
	'date_jnum13' => '13',
	'date_jnum14' => '14',
	'date_jnum15' => '15',
	'date_jnum16' => '16',
	'date_jnum17' => '17',
	'date_jnum18' => '18',
	'date_jnum19' => '19',
	'date_jnum2' => '2',
	'date_jnum20' => '20',
	'date_jnum21' => '21',
	'date_jnum22' => '22',
	'date_jnum23' => '23',
	'date_jnum24' => '24',
	'date_jnum25' => '25',
	'date_jnum26' => '26',
	'date_jnum27' => '27',
	'date_jnum28' => '28',
	'date_jnum29' => '29',
	'date_jnum3' => '3',
	'date_jnum30' => '30',
	'date_jnum31' => '31',
	'date_jnum4' => '4',
	'date_jnum5' => '5',
	'date_jnum6' => '6',
	'date_jnum7' => '7',
	'date_jnum8' => '8',
	'date_jnum9' => '9',
	'date_jour_1' => 'Chủ Nhật',
	'date_jour_1_abbr' => 'CN',
	'date_jour_1_initiale' => 'CN',
	'date_jour_2' => 'Thứ Hai',
	'date_jour_2_abbr' => 'T.Hai',
	'date_jour_2_initiale' => 'T2',
	'date_jour_3' => 'Thứ Ba',
	'date_jour_3_abbr' => 'T.Ba',
	'date_jour_3_initiale' => 'T3',
	'date_jour_4' => 'Thứ Tư',
	'date_jour_4_abbr' => 'T.Tư',
	'date_jour_4_initiale' => 'T4',
	'date_jour_5' => 'Thứ Năm',
	'date_jour_5_abbr' => 'T.Năm',
	'date_jour_5_initiale' => 'T5',
	'date_jour_6' => 'Thứ Sáu',
	'date_jour_6_abbr' => 'T.Sáu',
	'date_jour_6_initiale' => 'T6',
	'date_jour_7' => 'Thứ Bảy',
	'date_jour_7_abbr' => 'T.Bảy',
	'date_jour_7_initiale' => 'T7',
	'date_jours' => 'ngày',
	'date_minutes' => 'phút',
	'date_mois' => 'tháng',
	'date_mois_1' => 'Tháng Giêng',
	'date_mois_10' => 'Tháng Mười',
	'date_mois_11' => 'Tháng Mười Một',
	'date_mois_12' => 'Tháng Mười Hai',
	'date_mois_2' => 'Tháng Hai',
	'date_mois_3' => 'Tháng Ba',
	'date_mois_4' => 'Tháng Tư',
	'date_mois_5' => 'Tháng Năm',
	'date_mois_6' => 'Tháng Sáu',
	'date_mois_7' => 'Tháng Bảy',
	'date_mois_8' => 'Tháng Tám',
	'date_mois_9' => 'Tháng Chín',
	'date_saison_1' => 'mùa đông',
	'date_saison_2' => 'mùa xuân',
	'date_saison_3' => 'mùa hè',
	'date_saison_4' => 'mùa thu',
	'date_semaines' => 'tuần',
	'dirs_commencer' => ' để thực sự bắt đầu việc thiết trí',
	'dirs_preliminaire' => 'Tiên khởi: <b>Thiết kế quyền hạn ra/vô</b>',
	'dirs_probleme_droits' => 'Có vấn đề với quyền hạn ra/vô',
	'dirs_repertoires_absents' => '<b>Không tìm thấy các ngăn chứa sau đây: <ul>@bad_dirs@.</ul> </b>
  <p>Có thể là vì khác biệt chữ thường, chữ HOA.
  Xin xem lại cách đánh vần tên các ngăn chứa này cho đúng.
  Nếu cần phải sửa, dùng FTP để sửa.
  </p><p>Sau đó, bạn có thể</p>', # MODIF
	'dirs_repertoires_suivants' => '<b>Những ngăn sau đây không được phép Viết: <ul>@bad_dirs@.</ul> </b>

<p>Để thay đổi, dùng FTP vào thay đổi quyền hạn ra/vô của từng ngăn. Thể thức này có ghi trong cẩm nang sử dụng.
</p><p>Khi nào thực hiện xong, bạn có thể</p>', # MODIF
	'double_occurrence' => 'Hai lần', # MODIF

	// E
	'envoi_via_le_site' => 'Gửi từ trang web',
	'erreur' => 'Lỗi',
	'erreur_balise_non_fermee' => 'tag cuối cùng chưa đóng:',
	'erreur_texte' => 'lỗi',

	// F
	'fichier_introuvable' => 'Không tìm rà hồ sơ @fichier@', # MODIF
	'form_deja_inscrit' => 'Bạn đã ghi danh rồi.',
	'form_email_non_valide' => 'Địa chỉ email của bạn không đúng.',
	'form_forum_access_refuse' => 'Bạn không có quyền vào trang web này nữa.',
	'form_forum_bonjour' => 'Chào bạn @nom@,',
	'form_forum_email_deja_enregistre' => 'Địa chỉ email này đã dùng ghi danh rồi, bạn có thể dùng mật mã của bạn.',
	'form_forum_identifiant_mail' => 'Danh tánh (ID) mới của bạn đã được gửi bằng email.',
	'form_forum_identifiants' => 'Danh tánh (ID) cá nhân',
	'form_forum_indiquer_nom_email' => 'Cho vào tên và địa chỉ email của bạn. Bạn sẽ nhận được danh tánh (ID) cá nhân qua email sau đó.',
	'form_forum_login' => 'login:',
	'form_forum_message_auto' => '(đây là thư tín tự động)',
	'form_forum_pass' => 'mật mã:',
	'form_forum_probleme_mail' => 'Có vấn đề với email: Tên gọi (ID) không gửi đi được.',
	'form_forum_voici1' => 'Đây là tên gọi của bạn để tham gia vào các diễn đàn
"@nom_site_spip@" (@adresse_site@):',
	'form_forum_voici2' => 'Đây là tên gọi của bạn để nộp bài vào trang web 
"@nom_site_spip@"(@adresse_login@):',
	'form_indiquer_email' => 'Xin cho vào địa chỉ email của bạn.',
	'form_indiquer_nom' => 'Xin cho vào tên bạn.',
	'form_indiquer_nom_site' => 'Xin cho vào tên của website bạn.',
	'form_pet_deja_enregistre' => 'Website này đã được ghi danh',
	'form_pet_signature_pasprise' => 'Chữ ký bạn đã bị lờ đi.',
	'form_prop_confirmer_envoi' => 'Xác nhận thông báo gửi đi',
	'form_prop_description' => 'Mô tả/bình luận',
	'form_prop_enregistre' => 'Đề nghị của bạn đã được ghi nhận, nó sẽ xuất hiện online sau khi được quản trị viên thông qua.',
	'form_prop_envoyer' => 'Gửi thư tín',
	'form_prop_indiquer_email' => 'Xin cho vào địa chỉ email',
	'form_prop_indiquer_nom_site' => 'Xin cho vào tên của trang web.',
	'form_prop_indiquer_sujet' => 'Xin điền vào tựa đề',
	'form_prop_message_envoye' => 'Đã gửi thư tín',
	'form_prop_non_enregistre' => 'Đề nghị của bạn chưa được lưu trữ.',
	'form_prop_sujet' => 'Tựa đề',
	'form_prop_url_site' => 'URL của trang web', # MODIF
	'forum_non_inscrit' => 'Hoặc là bạn chưa ghi danh, hoặc địa chỉ hay mật mã không đúng.',
	'forum_par_auteur' => 'bởi @auteur@',
	'forum_titre_erreur' => 'Có lỗi...',

	// I
	'ical_texte_rss_articles' => 'Hồ sơ «backend» của các bài trên trang web này ở địa chỉ:',
	'ical_texte_rss_articles2' => 'Bạn cũng có thể lấy hồ sơ «backend» cho các bài của từng đề mục:',
	'ical_texte_rss_breves' => 'Còn có một hồ sơ cho các tin ngắn. Nếu bạn thêm số đề mục, bạn chỉ lấy dược tin ngắn của đề mục này.',
	'icone_a_suivre' => 'Nơi bắt đầu',
	'icone_admin_site' => 'Quản trị website',
	'icone_agenda' => 'Chương trình nghị sự và thư tín',
	'icone_aide_ligne' => 'Giúp đỡ',
	'icone_articles' => 'Bài',
	'icone_auteurs' => 'Ban biên tập',
	'icone_brouteur' => 'Xem lẹ',
	'icone_configuration_site' => 'Cấu hình',
	'icone_configurer_site' => 'Sửa cấu hình Website',
	'icone_creer_nouvel_auteur' => 'Thêm một tác giả mới',
	'icone_creer_rubrique' => 'Thêm một đề mục mới ',
	'icone_creer_sous_rubrique' => 'Thêm một đề mục phụ',
	'icone_deconnecter' => 'Rời khỏi',
	'icone_discussions' => 'Thảo luận',
	'icone_doc_rubrique' => 'Tài liệu của đề mục',
	'icone_ecrire_article' => 'Viết một bài mới',
	'icone_edition_site' => 'Sửa đổi',
	'icone_gestion_langues' => 'Quản trị ngôn ngữ',
	'icone_informations_personnelles' => 'Dữ kiện cá nhân',
	'icone_interface_complet' => 'Xem tất cả',
	'icone_interface_simple' => 'Xem đơn giản',
	'icone_maintenance_site' => 'Bảo trì',
	'icone_messagerie_personnelle' => 'Thư tín cá nhân',
	'icone_repartition_debut' => 'Cho xem phân loại từ ban đầu',
	'icone_rubriques' => 'Ðề Mục',
	'icone_sauver_site' => 'Lưu trữ database',
	'icone_site_entier' => 'Tất cả bài trong website ',
	'icone_sites_references' => 'Liên kết',
	'icone_statistiques' => 'Thống kê tổng quát',
	'icone_suivi_activite' => 'Những việc của Ban Biên Tập',
	'icone_suivi_actualite' => 'Tiến triển của trang web',
	'icone_suivi_pettions' => 'Quản trị thỉnh nguyện thư',
	'icone_suivi_revisions' => 'Cập nhật bài vở',
	'icone_supprimer_document' => 'Xóa tài liệu này',
	'icone_supprimer_image' => 'Xóa hình này',
	'icone_tous_articles' => 'Tất cả bài vở của bạn',
	'icone_tous_auteur' => 'Các tác giả',
	'icone_visiter_site' => 'Trở về trang nhà', # MODIF
	'icone_voir_en_ligne' => 'Xem online',
	'img_indisponible' => 'hình không có',
	'impossible' => 'không thể được',
	'info_a_suivre' => 'NƠI BẮT ĐẦU»',
	'info_acces_interdit' => 'Không vào/dùng được',
	'info_acces_refuse' => 'Không vào được',
	'info_action' => 'Công việc: @action@',
	'info_administrer_rubriques' => 'Bạn có thể quản trị đề mục này và các đề mục phụ',
	'info_adresse_non_indiquee' => 'Bạn không cho địa chỉ để thử nghiệm!',
	'info_aide' => 'GIÚP ĐỠ:',
	'info_ajouter_mot' => 'Thêm từ then chốt này',
	'info_annonce' => 'THÔNG BÁO',
	'info_annonces_generales' => 'Thông tin tổng quát:',
	'info_article_propose' => 'Bài đã nộp',
	'info_article_publie' => 'Bài đã phát hành',
	'info_article_redaction' => 'Bài đang soạn',
	'info_article_refuse' => 'Bài bị từ chối',
	'info_article_supprime' => 'Bài đã xóa',
	'info_articles' => 'Bài',
	'info_articles_a_valider' => 'Những bài chờ thông qua',
	'info_articles_proposes' => 'Bài vở đã nộp',
	'info_auteurs_nombre' => 'tác giả:',
	'info_authentification_ftp' => 'Xác nhận (dùng FTP).',
	'info_breves_2' => 'tin ngắn',
	'info_connexion_refusee' => 'Không nối vào được',
	'info_contact_developpeur' => 'Xin liên lạc với lập trình viên.',
	'info_contenance' => 'Website có:',
	'info_contribution' => 'thư tín của diễn đàn', # MODIF
	'info_copyright' => '@spip@ là nhu liệu miễn phí phổ biến @lien_gpl@.',
	'info_copyright_doc' => 'Để biết thêm, xin vào xem trang <a href="@spipnet@">http://www.spip.net/vi</a>.', # MODIF
	'info_copyright_gpl' => 'theo giấp phép GPL',
	'info_cours_edition' => 'Bài của bạn đang soạn', # MODIF
	'info_creer_repertoire' => 'Xin lập ra một hồ sơ hay một ngăn mang tên:',
	'info_creer_repertoire_2' => 'trong ngăn phụ <b>@repertoire@</b>, kế đó', # MODIF
	'info_creer_vignette' => 'tự động tạo ra các hình mẫu nhỏ',
	'info_deplier' => 'Mở ra',
	'info_descriptif_nombre' => 'Mô tả:',
	'info_description' => 'Tóm lược:',
	'info_description_2' => 'Tóm lược:',
	'info_dimension' => 'Khổ:',
	'info_ecire_message_prive' => 'Viết thư tín riêng',
	'info_email_invalide' => 'Địa chỉ email không đúng.',
	'info_en_cours_validation' => 'Bài viết đang soạn',
	'info_en_ligne' => 'Đang online:',
	'info_envoyer_message_prive' => 'Gửi thư riêng cho tác giả này',
	'info_erreur_requete' => 'Vấn đáp có lỗi: ',
	'info_erreur_squelette2' => 'Không có mẫu cho trang web này. Không tìm thay hồ sơ <b>@fichier@</b>...',
	'info_erreur_systeme' => 'Thông báo lỗi số (errno @errsys@)',
	'info_erreur_systeme2' => 'Đĩa cứng có thể đã đầy hay là database bị hư.<br />
<span style="color:red;">Xin <a href=\'@script@\'>sửa Database</a>, hay liên lạc với quản trị viên máy.</span>', # MODIF
	'info_fini' => 'Xong rồi! ',
	'info_format_image' => 'Dạng hình dùng để lập ra hình mẫu: @gd_formats@.',
	'info_format_non_defini' => 'Dạng không định rõ',
	'info_grand_ecran' => 'Xem dạng lớn',
	'info_image_aide' => 'GIÚP ĐỠ',
	'info_image_process_titre' => 'Cách tạo hình mẫu nhỏ',
	'info_impossible_lire_page' => '<b>Lỗi!</b> Không đọc được trang <tt><html>@test_proxy@</html></tt> qua proxy <tt>', # MODIF
	'info_installation_systeme_publication' => 'Thiết trí hệ thống phát hành ...',
	'info_installer_documents' => 'Bạn có thể cài đặt tất cả tài liệu trong ngăn @upload@.', # MODIF
	'info_installer_ftp' => 'Là quản trị viên, bạn có thể cài đặt (dùng FTP) các hồ sơ trong ngăn @upload@ rồi chọn lựa chúng sau đó trực tiếp từ đây.', # MODIF
	'info_installer_images' => 'Bạn có thể cài đặt hình trong dạng JPEG, GIF và PNG.',
	'info_installer_images_dossier' => 'Cài đạt hình trong ngăn @upload@ để có thể chọn lựa chúng từ đây.',
	'info_interface_complete' => 'Xem tất cả',
	'info_interface_simple' => 'Xem đơn giản',
	'info_joindre_document_article' => 'Bạn có thể đính kèm vào bài viết các hồ sơ trong dạng',
	'info_joindre_document_rubrique' => 'Bạn có thể thêm vào đề mục này các hồ sơ trong dạng',
	'info_joindre_documents_article' => ' Bạn có thể đính kèm vào bài viết các hồ sơ trong dạng: ',
	'info_l_article' => 'bài',
	'info_la_breve' => 'tin ngắn',
	'info_la_rubrique' => 'đề mục',
	'info_langue_principale' => 'Ngôn ngữ của website',
	'info_largeur_vignette' => '@largeur_vignette@ x @hauteur_vignette@ chấm',
	'info_les_auteurs_1' => 'của @les_auteurs@ ',
	'info_logo_format_interdit' => 'Chỉ chấp nhận logo trong các dạng @formats@.',
	'info_logo_max_poids' => 'Logo phải nhỏ hơn @maxi@ (Hồ sơ này là @actuel@).',
	'info_mail_fournisseur' => ' you@isp.com',
	'info_message_2' => 'THƯ TÍN',
	'info_message_supprime' => 'THƯ TÍN ĐƯỢC XÓA',
	'info_mise_en_ligne' => 'Ngày đăng tải online:',
	'info_modification_parametres_securite' => 'Sửa đổi các thông số an ninh',
	'info_mois_courant' => 'Trong tháng:',
	'info_mot_cle_ajoute' => 'Từ then chốt sau được thêm vào ',
	'info_multi_herit' => 'Ngôn ngữ định sẵn',
	'info_multi_langues_soulignees' => '<u>Các ngôn ngữ có gạch dưới</u> có nghĩa là phần văn bản của giao diện được dịch qua ngôn ngữ đó. Nếu bạn chọn một ngôn ngữ đó, các phần văn bản (ngày tháng, mẫu đơn) sẽ được tự động dịch qua. Còn những ngôn ngữ không có hàng gạch dưới thì không có bản dịch. Phần giao diện sẽ hiện ra bằng ngôn ngữ chính của trang web.', # MODIF
	'info_multilinguisme' => 'Dụng nhiều thứ tiếng',
	'info_nom_non_utilisateurs_connectes' => 'Tên bạn không thấy có trong danh sách những người dùng đang nối vào.',
	'info_nom_utilisateurs_connectes' => 'Tên bạn có trong danh sách những người dùng đang nối vào.',
	'info_nombre_en_ligne' => 'Online bây giờ:',
	'info_non_resultat' => 'Không có kết quả cho "@cherche_mot@"',
	'info_non_utilisation_messagerie' => 'Bạn không dùng phương tiện thư tín nộ bộ của website này.',
	'info_nouveau_message' => 'CÓ THƯ TÍN MỚI',
	'info_nouveaux_messages' => 'BẠN CÓ @total_messages@ THƯ TÍN MỚI',
	'info_numero_abbreviation' => 'Số ',
	'info_pense_bete' => 'GHI NHỚ',
	'info_petit_ecran' => 'Xem dạng nhỏ',
	'info_pixels' => 'chấm',
	'info_plusieurs_mots_trouves' => 'Tìm thấy một số từ then chốt cho "@cherche_mot@":',
	'info_portfolio_automatique' => 'Portfolio tự động:',
	'info_premier_resultat' => '[@debut_limit@ kết quả đầu tiên trong số @total@]',
	'info_premier_resultat_sur' => '[@debut_limit@ kết quả đầu tiên trong số @total@]',
	'info_propose_1' => '[@nom_site_spip@] Nộp: @titre@',
	'info_propose_2' => 'Bài được nộp
-----------------',
	'info_propose_3' => 'Bài "@titre@" được nộp để phát hành.',
	'info_propose_4' => 'Bạn nên xem lại và cho biết ý kiến',
	'info_propose_5' => 'trong diễn đàn liên hệ. Qua địa chỉ:',
	'info_publie_01' => 'Bài "@titre@" được chấp thuận bởi @connect_nom@.',
	'info_publie_1' => '[@nom_site_spip@] ĐĂNG TẢI: @titre@',
	'info_publie_2' => 'Bài được đăng tải
-----------------',
	'info_rechercher' => 'Tìm kiếm',
	'info_rechercher_02' => 'Tìm:',
	'info_remplacer_vignette' => 'Thay thế hình xem trước định sẵn bằng logo riêng:',
	'info_sans_titre_2' => 'không tựa đề',
	'info_selectionner_fichier' => 'Bạn có thể chọn một hồ trơ trong ngăn @upload@', # MODIF
	'info_selectionner_fichier_2' => 'Chọn một hồ sơ:',
	'info_supprimer_vignette' => 'xóa hình nhỏ xem trước',
	'info_symbole_bleu' => 'Ký hiệu <b>xanh dương</b> cho biết <b>bản ghi nhớ</b>: tức là thư tín cho riêng bạn.', # MODIF
	'info_symbole_jaune' => 'Ký hiệu <b>vàng</b> cho biết <b>thông báo đến tất cả chủ bút</b>: tất cả chủ bút có thể sửa đổi được, và chủ bút nào cũng nhìn thấy được.', # MODIF
	'info_symbole_vert' => 'Ký hiệu <b>xanh lá cây</b> cho biết <b>thư tín trao đổi với những người dùng</b> của website.', # MODIF
	'info_telecharger_nouveau_logo' => 'Đem/tải lên một logo mới:',
	'info_telecharger_ordinateur' => 'Đem/tải lên từ máy bạn:',
	'info_tous_resultats_enregistres' => '[Toàn bộ kết quả được ghi nhớ lại] ',
	'info_tout_afficher' => 'Xem tất cả',
	'info_travaux_texte' => 'Website này chưa được hoàn tất. Xin quý vị trở lại trong vài ngày sau.',
	'info_travaux_titre' => 'Website đang được xây dựng',
	'info_trop_resultat' => 'Quá nhiều kết quả cho "@cherche_mot@"; xin lọc lựa lại việc tìm kiếm.',
	'info_utilisation_messagerie_interne' => 'Bạn đang dùng phương tiện thư tín nội bộ của website. ',
	'info_valider_lien' => 'chấp thuận điểm nối kết này',
	'info_verifier_image' => ', xin kiểm lại xem hình bạn chuyển tải có đúng không.',
	'info_vignette_defaut' => 'Hình xem trước định sẵn',
	'info_vignette_personnalisee' => 'Hình xem trước có điều chỉnh',
	'info_visite' => 'thăm viếng:',
	'info_vos_rendez_vous' => 'Những lần hẹn sắp tới',
	'infos_vos_pense_bete' => 'Bản ghi nhớ của bạn', # MODIF

	// L
	'lien_afficher_icones_seuls' => 'Xem icon mà thôi',
	'lien_afficher_texte_icones' => 'Xem icon và chữ',
	'lien_afficher_texte_seul' => 'Xem chữ mà thôi',
	'lien_liberer' => 'phổ biến',
	'lien_liberer_tous' => 'Gỡ bỏ những bài này', # MODIF
	'lien_nouvea_pense_bete' => 'GHI NHỚ MỚI',
	'lien_nouveau_message' => 'THƯ TÍN MỚI',
	'lien_nouvelle_annonce' => 'THÔNG BÁO MỚI',
	'lien_petitions' => 'THỈNH NGUYỆN THƯ',
	'lien_popularite' => 'phổ thông: @popularite@%',
	'lien_racine_site' => 'GỐC WEBSITE',
	'lien_reessayer' => 'thử lai lần nữa',
	'lien_repondre_message' => 'Hồi âm thư tín này',
	'lien_supprimer' => 'xóa',
	'lien_tout_afficher' => 'Hiển thị tất cả',
	'lien_visite_site' => 'Vào trang web này',
	'lien_visites' => '@visites@ lần tới xem',
	'lien_voir_auteur' => 'Xem tác giả',
	'ligne' => 'Dòng',
	'login' => 'Đường nối',
	'login_acces_prive' => 'vào vùng riêng',
	'login_autre_identifiant' => 'nối với tên gọi (ID) khác',
	'login_cookie_accepte' => 'Điều chỉnh browser để chấp nhận chúng (ít nhất là cho website này).',
	'login_cookie_oblige' => 'Để nhận diện bạn cho chắc, bạn phải chấp nhận mở cookies lên.',
	'login_deconnexion_ok' => 'Ra khỏi.',
	'login_erreur_pass' => 'Có lỗi mật mã.',
	'login_espace_prive' => 'vùng riêng',
	'login_identifiant_inconnu' => 'Không biết danh tánh "@login@".',
	'login_login' => 'Login:',
	'login_login2' => 'Login (danh tánh để vào trang web):', # MODIF
	'login_login_pass_incorrect' => '(login hoặc mật mã không đúng).',
	'login_motpasseoublie' => 'quên mật mã?',
	'login_non_securise' => 'Cảnh báo, phiếu điền này không an toàn.
 Nếu bạn không muốn mật mã bị chặn lấy trên net,
 xin mở Javascript trong browser lên và',
	'login_nouvelle_tentative' => 'Thử lại',
	'login_par_ici' => 'Bạn được ghi danh ... lối này ...',
	'login_pass2' => 'Mật mã:',
	'login_preferez_refuser' => '<b>Nếu bạn chọn không mở cookies lên</b>, có một cách khác để vào (không an toàn bằng):',
	'login_recharger' => 'nạp lại trang này',
	'login_rester_identifie' => 'Vẫn còn nhớ trong vòng vài ngày', # MODIF
	'login_retour_public' => 'Trở lại trang web công cộng',
	'login_retour_site' => 'Trở lại trang web công cộng',
	'login_retoursitepublic' => 'trở lại trang web công cộng',
	'login_sinscrire' => 'ghi danh',
	'login_test_navigateur' => 'thử browser/nối lại',
	'login_verifiez_navigateur' => '(Tuy nhiên, kiểm lại để biết là browser không có nhớ mật mã của bạn...)',

	// M
	'masquer_trad' => 'dấu các bản dịch',
	'module_fichiers_langues' => 'Hồ sơ ngôn ngữ',

	// N
	'navigateur_pas_redirige' => 'Nếu browser của bạn không được hướng qua một địa chỉ URL mới, xin bấm vô đây để tiếp tục.',
	'numero' => 'Số',

	// O
	'occurence' => 'Lần',
	'onglet_affacer_base' => 'Xóa bỏ database',
	'onglet_auteur' => 'Tác giả',
	'onglet_contenu_site' => 'Đặc điểm căn bản',
	'onglet_evolution_visite_mod' => 'Tiến trình',
	'onglet_fonctions_avances' => 'Đặc điểm phụ trội',
	'onglet_informations_personnelles' => 'Dữ kiện cá nhân',
	'onglet_interactivite' => 'Đặc điểm thông tin',
	'onglet_messagerie' => 'Thư tín',
	'onglet_repartition_rubrique' => 'Phân loại theo đề mục',
	'onglet_save_restaur_base' => 'Lưu trữ/phục hồi database',
	'onglet_vider_cache' => 'Dọn sạch cache',

	// P
	'pass_choix_pass' => 'Xin chọn mật mã mới:',
	'pass_erreur' => 'Có lỗi',
	'pass_erreur_acces_refuse' => '<b>Lỗi:</b> bạn không có quyền hạn vào website này nữa.',
	'pass_erreur_code_inconnu' => '<b>Lỗi:</b> mã số này không trùng hợp với những nhân sự được phép vào website này.',
	'pass_erreur_non_enregistre' => '<b>Lỗi:</b> Địa chỉ <tt>@email_oubli@</tt> chưa có ghi danh với website.',
	'pass_erreur_non_valide' => '<b>Lỗi:</b> Email <tt>@email_oubli@</tt> không đúng!',
	'pass_erreur_probleme_technique' => '<b>Lỗi:</b> Không gửi email đi được vì trục trặc kỹ thuật.',
	'pass_espace_prive_bla' => 'Khách thăm viếng chỉ vào được vùng riêng sau khi ghi danh. Ghi danh rồi, bạn có thể xem các bài vở đang soạn, nộp bài vào và tham gia vào các diễn đàn.',
	'pass_forum_bla' => 'Diễn đàn bạn muốn vào chỉ dành riêng cho các vị khách có ghi danh.',
	'pass_indiquez_cidessous' => 'Đánh vào địa chỉ email mà bạn đã dùng ghi danh trước đây. Sau đó, bạn sẽ nhận qua email chi tiết chỉ dẫn cách tìm lại phép ra/vô.',
	'pass_mail_passcookie' => '(đây là thư tín tự động)

Để tìm lại cách ra/vô webiste 
@nom_site_spip@ (@adresse_site@)

Xin vào địa chỉ sau đây:
    @sendcookie@

Bạn cho vào mật mã mới để vào lại trang web.', # MODIF
	'pass_mot_oublie' => 'Quên mất mật mã',
	'pass_nouveau_enregistre' => 'Mật mã mới đã được lưu trữ.',
	'pass_nouveau_pass' => 'Mật mã mới',
	'pass_ok' => 'OK',
	'pass_oubli_mot' => 'Quên mật mã',
	'pass_quitter_fenetre' => 'Rời bỏ khung đó',
	'pass_rappel_login' => 'Lưu ý: login của bạn là "@login@".',
	'pass_recevoir_mail' => 'Bạn sẽ nhận qua email chi tiết chỉ dẫn cách thu hồi phép ra/vô trang web.', # MODIF
	'pass_retour_public' => 'Trở lại trang web',
	'pass_rien_a_faire_ici' => 'Không có gì ở đây.',
	'pass_vousinscrire' => 'Ghi danh với website',
	'precedent' => 'trước',
	'previsualisation' => 'Xem trước',
	'previsualiser' => 'Cho xem trước',

	// R
	'retour' => 'Trở lại',

	// S
	'spip_conforme_dtd' => 'SPIP xác nhận trang này theo đúng tiêu chuẩn với DOCTYPE của SPIP:',
	'squelette' => 'bản mẫu',
	'squelette_inclus_ligne' => 'bản mẫu đính kèm, dòng',
	'squelette_ligne' => 'bản mẫu, dòng',
	'stats_visites_et_popularite' => '@visites@ lần viếng; mức phổ thông: @popularite@',
	'suivant' => 'kế tiếp',

	// T
	'taille_ko' => '@taille@ kb',
	'taille_mo' => '@taille@ Mb',
	'taille_octets' => '@taille@ bytes',
	'texte_actualite_site_1' => 'Khi bạn trở nên quen thuộc với cách thức trình bày trong website này, bấm vào «',
	'texte_actualite_site_2' => 'Xem tất cả',
	'texte_actualite_site_3' => '» để xem những đặc điểm khác.',
	'texte_creation_automatique_vignette' => 'Website có khả năng tạo lập tự động các hình mẫu.
Nếu bạn đem vào những hình ảnh trong dạng  @gd_formats@, chúng sẽ có hình mẫu với khổ tối đa là @taille_preview@ chấm. ',
	'texte_documents_associes' => 'Các tài liệu sau đây có liên đới với bài này, nhưng chúng không được độn trực tiếp vào. Dựa theo bố trí của website, chúng trông như là tài liệu đính kèm. ',
	'texte_erreur_mise_niveau_base' => 'Có lỗi database trong lúc nâng cấp. Hình <b>@fichier@</b> không chuyển vô được trong (bài @id_article@).<p> Hãy lưu ý cho kỹ lời nhắn này, thử lại việc nâng cấp, và cuối cùng kiểm lại xem hình có hiện ra trong bài không. ', # MODIF
	'texte_inc_auth_1' => 'Bạn bảo rằng login của bạn là <b>@auth_login@</b>, nhưng login này không có trong database. Tìm cách', # MODIF
	'texte_inc_auth_2' => 'nối lại',
	'texte_inc_auth_3' => 'bằng cách ra khỏi và khởi động lại browser, nếu cần thiết.',
	'texte_inc_config' => 'Những sửa đổi dưới đây tác động đến sự vận hành của website. Khuyến cáo bạn không nên đụng vô trừ phi bạn nắm vững sự vận hành của hệ thống SPIP. <br /><br /><b>Tốt hơn hết, bạn nên để cho người webmaster chính lo các việc này.</b>', # MODIF
	'texte_inc_meta_1' => 'Có vấn đề khi viết hồ sơ <code>@fichier@</code>.Là quản lý viên của website, xin bạn ', # MODIF
	'texte_inc_meta_2' => 'kiểm lại quyền hạn viết',
	'texte_inc_meta_3' => 'của ngăn <code>@repertoire@</code>.', # MODIF
	'texte_statut_en_cours_redaction' => 'đang viết/soạn',
	'texte_statut_poubelle' => 'vô thùng rác',
	'texte_statut_propose_evaluation' => 'được đề nghị',
	'texte_statut_publie' => 'được đăng lên',
	'texte_statut_refuse' => 'bị từ chối',
	'titre_ajouter_mot_cle' => 'THÊM MỘT TỪ THÊN CHỐT:',
	'titre_cadre_raccourcis' => 'NGÕ TẮT:',
	'titre_changer_couleur_interface' => 'Thay đổi màu của giao diện',
	'titre_image_admin_article' => 'Bạn có thể quản trị bài này',
	'titre_image_administrateur' => 'Quản trị viên',
	'titre_image_aide' => 'Giúp đỡ trên tiết mục này',
	'titre_image_auteur_supprime' => 'Tác giả bị xoá',
	'titre_image_redacteur' => 'Tác giả không có quyền',
	'titre_image_redacteur_02' => 'Tác giả',
	'titre_image_visiteur' => 'Khách',
	'titre_joindre_document' => 'ĐÍNH KÈM MỘT HỒ SƠ',
	'titre_mots_cles' => 'TỪ THEN CHỐT',
	'titre_probleme_technique' => 'Báo động: trục trặc kỹ thuật (SQL server) thành ra không vào được chỗ này của trang web.<p>Xin thông cảm.', # MODIF
	'titre_publier_document' => 'PHÁT HÀNH MỘT TÀI LIỆU TRONG ĐỀ MỤC NÀY',
	'titre_statistiques' => 'Thống Kê',
	'titre_titre_document' => 'Tựa bài:',
	'trad_reference' => '(bài nối kết)', # MODIF

	// Z
	'zbug_balise_b_aval' => ': B tag too late in loop',
	'zbug_balise_inexistante' => 'erreur @from@: la balise #@balise@ n’existe pas', # MODIF
	'zbug_boucle' => 'loop',
	'zbug_boucle_recursive_undef' => 'undefined recursive loop', # MODIF
	'zbug_champ_hors_boucle' => 'Field @champ@ outside loop',
	'zbug_champ_hors_motif' => 'Field @champ@ outside loop tagged @motif@', # MODIF
	'zbug_code' => 'mã',
	'zbug_critere_inconnu' => 'unknown criterion @critere@', # MODIF
	'zbug_distant_interdit' => 'external data forbidden', # MODIF
	'zbug_doublon_table_sans_cle_primaire' => 'doublons sur une table sans clef primaire atomique', # MODIF
	'zbug_doublon_table_sans_index' => 'doublons sur une table sans index', # MODIF
	'zbug_erreur_boucle_double' => 'BOUCLE@id@: Chỉ được dùng một lần ', # MODIF
	'zbug_erreur_boucle_fermant' => 'BOUCLE@id@: chưa dược dóng lại ', # MODIF
	'zbug_erreur_boucle_syntaxe' => 'Cách viết vòng (boucle) này không đúng.', # MODIF
	'zbug_erreur_execution_page' => 'error in page calculation', # MODIF
	'zbug_erreur_filtre' => 'Sai lầm : Bạn chưa xác định bộ lọc (filtre) <b>« @filtre@ »</b> nầy. ', # MODIF
	'zbug_erreur_meme_parent' => '{meme_parent} only applies to loops (FORUMS) and (RUBRIQUES)', # MODIF
	'zbug_erreur_squelette' => 'Error(s) in template',
	'zbug_info_erreur_squelette' => 'Có lỗi trên Website',
	'zbug_inversion_ordre_inexistant' => 'reversal of nonexistent order', # MODIF
	'zbug_pagination_sans_critere' => '#PAGINATION sans critère {pagination} ou employé dans une boucle recursive', # MODIF
	'zbug_parametres_inclus_incorrects' => 'Wrong inclusion parameters', # MODIF
	'zbug_profile' => 'Thời gian tính toán: @time@',
	'zbug_resultat' => 'kết quả',
	'zbug_serveur_indefini' => 'undefined SQL server', # MODIF
	'zbug_table_inconnue' => 'Unknown SQL table "@table@"',
	'zxml_inconnu_id' => 'chi tiết ID không biết',
	'zxml_survoler' => 'để xem chi tiết đúng, di chuyển con chuột lên trên',
	'zxml_vu' => 'đã thấy trước đây'
);
